module Feature.Sharing.Mongo ( getAllDocs, findByLink ) where

import Core.Types

import Control.Monad.Reader (MonadIO, lift, ask)
import Data.Maybe
import Data.Text            (Text)
import Database.MongoDB
import Prelude

findByLink :: String -> PurrAction (Maybe Document)
findByLink link = do
  col      <- confCollection
  dataConn <- dataAccess
  dataConn  $ findOne (select ["link" =: link] col)

getAllDocs :: PurrAction [Document]
getAllDocs = do
  col      <- confCollection
  dataConn <- dataAccess
  dataConn  $ find (select [] col)
    >>= rest

dataAccess :: MonadIO m => PurrAction (Action m a -> m a)
dataAccess = do
  appConfig <- lift ask
  return     $ access
    (mongoPipe         $ dbconn appConfig)
    (mongoAccessMode   $ dbconn appConfig)
    (mongoDatabase     $ dbconn appConfig)

confCollection :: PurrAction Text
confCollection = do
  appConfig <- lift ask
  return     $ collection $ res appConfig
